import 'dart:async';

import 'package:flutter/material.dart';
import 'package:itplugin/controls/it_button.dart';
import 'package:itplugin/controls/it_dialogs.dart';
import 'package:itplugin/controls/it_drawer_wdg.dart';
import 'package:itplugin/controls/it_flat_button.dart';
import 'package:itplugin/controls/it_grid.dart';
import 'package:itplugin/controls/it_rate.dart';
import 'package:itplugin/controls/it_text_field.dart';
import 'package:itplugin/itplugin.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  MyApp({Key key}) : super(key: key) {
    ItPlugin.loadingDialog = [
      CircularProgressIndicator(
        strokeWidth: 5,
      ),
      Padding(
        padding: const EdgeInsets.all(20.0),
        child: Text(
          "Carregando",
          style: TextStyle(fontSize: 30, color: Colors.white),
        ),
      )
    ];
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: "Teste",
      home: HomePage(),
    );
  }
}

class HomePage extends StatefulWidget {
  HomePage({Key key}) : super(key: key);

  @override
  _HomePageState createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  GlobalKey<ScaffoldState> _scaffoldKey = GlobalKey();

  ItDrawerPrefs leftDrawer = ItDrawerPrefs(
      header: Header(
          onTap: () {},
          child: Container(
            color: Colors.yellow,
            alignment: Alignment.center,
            child: Column(
              mainAxisAlignment: MainAxisAlignment.spaceEvenly,
              children: [
                Text(
                  "ItDrawer",
                  style: TextStyle(fontSize: 20),
                ),
                Text(
                  "Este é o container do Header",
                  style: TextStyle(fontSize: 20),
                ),
              ],
            ),
          )),
      body: Body(
          child: Container(
        padding: EdgeInsets.symmetric(vertical: 10),
        color: Colors.blue,
        alignment: Alignment.center,
        child: Column(
          mainAxisAlignment: MainAxisAlignment.spaceEvenly,
          children: [
            Text(
              "Este é o container do Body",
              style: TextStyle(fontSize: 20),
            ),
            Text(
              "indentico ao SingleChildScrollView",
              style: TextStyle(fontSize: 16),
            ),
          ],
        ),
      )));

  ItDrawerPrefs rightDrawer = ItDrawerPrefs(
      header: Header(
          onTap: () {},
          child: Container(
            color: Colors.purple,
            alignment: Alignment.center,
            child: Column(
              mainAxisAlignment: MainAxisAlignment.spaceEvenly,
              children: [
                Text(
                  "ItDrawer (Esquerda)",
                  style: TextStyle(fontSize: 20),
                ),
                Text(
                  "Este é o container do Header",
                  style: TextStyle(fontSize: 20),
                ),
              ],
            ),
          )),
      body: Body(
          child: Container(
        padding: EdgeInsets.symmetric(vertical: 10),
        color: Colors.green,
        alignment: Alignment.center,
        child: Column(
          mainAxisAlignment: MainAxisAlignment.spaceEvenly,
          children: [
            Text(
              "Este é o container do Body",
              style: TextStyle(fontSize: 20),
            ),
            Text(
              "indentico ao SingleChildScrollView",
              style: TextStyle(fontSize: 16),
            ),
          ],
        ),
      )));

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        key: _scaffoldKey,
        drawer: ItDrawer(prefs: leftDrawer),
        endDrawer: ItDrawer(prefs: rightDrawer),
        appBar: AppBar(
          title: Text("ItPlugin"),
        ),
        body: Container(
          child: Center(
            child: Container(
              alignment: Alignment.topCenter,
              child: SingleChildScrollView(
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: [
                    Container(
                      alignment: Alignment.centerLeft,
                      padding: EdgeInsets.all(20),
                      child: Column(
                        children: [
                          Container(
                            child: Text(
                              "Dialogs",
                              style: TextStyle(fontSize: 20),
                            ),
                          )
                        ],
                      ),
                    ),
                    Container(
                      padding: EdgeInsets.only(bottom: 5, top: 5),
                      child: ItButton(
                        "Show Loading",
                        onClick: () {
                          ItDialogs.showLoading(context);
                          Future.delayed(const Duration(seconds: 3), () {
                            ItDialogs.hideLoading(context);
                          });
                        },
                      ),
                    ),
                    Container(
                      padding: EdgeInsets.only(bottom: 5, top: 5),
                      child: ItButton(
                        "Show Widget Dialog",
                        onClick: () {
                          ItDialogs.showWidgetDialog(context,
                              child: Container(
                                child: Text("Test"),
                              ));
                        },
                      ),
                    ),
                    Container(
                      padding: EdgeInsets.only(bottom: 5, top: 5),
                      child: ItButton(
                        "Show Alert Dialog",
                        onClick: () {
                          ItDialogs.showAlertDialog(context,
                              prefs: ItAlertDialogPrefs("Title", "Message"));
                        },
                      ),
                    ),
                    Container(
                      alignment: Alignment.centerLeft,
                      padding: EdgeInsets.all(20),
                      child: Column(
                        children: [
                          Container(
                            child: Text(
                              "Controls",
                              style: TextStyle(fontSize: 20),
                            ),
                          )
                        ],
                      ),
                    ),
                    Container(
                      padding: EdgeInsets.only(bottom: 5, top: 5),
                      child: ItButton(
                        "ItButton",
                        color: Colors.red,
                        onClick: () {},
                      ),
                    ),
                    Container(
                      padding: EdgeInsets.only(bottom: 5, top: 5),
                      child: ItFlatButton(
                        "ItFlatButton",
                        onClick: () {},
                      ),
                    ),
                    Container(
                      padding: EdgeInsets.only(bottom: 5, top: 5),
                      child: ItFlatButton(
                        "ItFlatButton - CustomBackground",
                        background: Background(
                          backgroundColor: Colors.blue,
                          child: Container(
                            child: Column(
                              mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                              children: [
                                Container(
                                  child: Text("Este é o widget de fundo",
                                      style: TextStyle(color: Colors.white)),
                                ),
                                Container(
                                  child: Text("Este é o widget de fundo",
                                      style: TextStyle(color: Colors.white)),
                                ),
                                Container(
                                  child: Text("Este é o widget de fundo",
                                      style: TextStyle(color: Colors.white)),
                                ),
                                Container(
                                  child: Text("Este é o widget de fundo",
                                      style: TextStyle(color: Colors.white)),
                                ),
                                Container(
                                  child: Text("Este é o widget de fundo",
                                      style: TextStyle(color: Colors.white)),
                                ),
                              ],
                            ),
                          ),
                        ),
                        width: 200,
                        height: 200,
                        textStyle: TextStyle(color: Colors.red, fontSize: 20),
                        onClick: () {},
                      ),
                    ),
                    Container(
                      padding: EdgeInsets.only(bottom: 5, top: 5),
                      child: ItButton(
                        "Show ItDrawer (Direita)",
                        onClick: () {
                          _scaffoldKey.currentState.openDrawer();
                        },
                      ),
                    ),
                    Container(
                      padding: EdgeInsets.only(bottom: 5, top: 5),
                      child: ItButton(
                        "Show ItDrawer (Esquerda)",
                        onClick: () {
                          _scaffoldKey.currentState.openEndDrawer();
                        },
                      ),
                    ),
                    Container(
                      padding: EdgeInsets.all(20),
                      child: Column(
                        children: [
                          Container(
                            child: Text(
                              "ItGrid - centerAlign",
                              style: TextStyle(fontSize: 16),
                            ),
                          )
                        ],
                      ),
                    ),
                    Container(
                      child: ItGrid(
                        columns: 3,
                        crossAxisAlignment: CrossAxisAlignment.center,
                        children: [
                          SizedBox(
                            height: 100,
                            width: 100,
                            child: Container(
                                alignment: Alignment.center,
                                color: Colors.red,
                                child: Text(
                                  "Container 1",
                                  style: TextStyle(fontSize: 18),
                                )),
                          ),
                          SizedBox(
                            height: 100,
                            width: 100,
                            child: Container(
                                alignment: Alignment.center,
                                color: Colors.blue,
                                child: Text(
                                  "Container 2",
                                  style: TextStyle(fontSize: 18),
                                )),
                          ),
                          SizedBox(
                            height: 100,
                            width: 100,
                            child: Container(
                                alignment: Alignment.center,
                                color: Colors.yellow,
                                child: Text(
                                  "Container 3",
                                  style: TextStyle(fontSize: 18),
                                )),
                          ),
                          SizedBox(
                            height: 100,
                            width: 100,
                            child: Container(
                                alignment: Alignment.center,
                                color: Colors.purple,
                                child: Text(
                                  "Container 4",
                                  style: TextStyle(fontSize: 18),
                                )),
                          ),
                          SizedBox(
                            height: 100,
                            width: 100,
                            child: Container(
                                alignment: Alignment.center,
                                color: Colors.green,
                                child: Text(
                                  "Container 5",
                                  style: TextStyle(fontSize: 18),
                                )),
                          ),
                        ],
                      ),
                    ),
                    Container(
                      padding: EdgeInsets.all(20),
                      child: Column(
                        children: [
                          Container(
                            child: Text(
                              "ItGrid - leftAlign",
                              style: TextStyle(fontSize: 16),
                            ),
                          )
                        ],
                      ),
                    ),
                    Container(
                      child: ItGrid(
                        columns: 3,
                        children: [
                          SizedBox(
                            height: 100,
                            width: 100,
                            child: Container(
                                alignment: Alignment.center,
                                color: Colors.red,
                                child: Text(
                                  "Container 1",
                                  style: TextStyle(fontSize: 18),
                                )),
                          ),
                          SizedBox(
                            height: 100,
                            width: 100,
                            child: Container(
                                alignment: Alignment.center,
                                color: Colors.blue,
                                child: Text(
                                  "Container 2",
                                  style: TextStyle(fontSize: 18),
                                )),
                          ),
                          SizedBox(
                            height: 100,
                            width: 100,
                            child: Container(
                                alignment: Alignment.center,
                                color: Colors.yellow,
                                child: Text(
                                  "Container 3",
                                  style: TextStyle(fontSize: 18),
                                )),
                          ),
                          SizedBox(
                            height: 100,
                            width: 100,
                            child: Container(
                                alignment: Alignment.center,
                                color: Colors.purple,
                                child: Text(
                                  "Container 4",
                                  style: TextStyle(fontSize: 18),
                                )),
                          ),
                          SizedBox(
                            height: 100,
                            width: 100,
                            child: Container(
                                alignment: Alignment.center,
                                color: Colors.green,
                                child: Text(
                                  "Container 5",
                                  style: TextStyle(fontSize: 18),
                                )),
                          ),
                        ],
                      ),
                    ),
                    Container(
                      padding: EdgeInsets.all(20),
                      child: Column(
                        children: [
                          Container(
                            child: Text(
                              "ItGrid - rightAlign",
                              style: TextStyle(fontSize: 16),
                            ),
                          )
                        ],
                      ),
                    ),
                    Container(
                      child: ItGrid(
                        columns: 3,
                        crossAxisAlignment: CrossAxisAlignment.end,
                        children: [
                          SizedBox(
                            height: 100,
                            width: 100,
                            child: Container(
                                alignment: Alignment.center,
                                color: Colors.red,
                                child: Text(
                                  "Container 1",
                                  style: TextStyle(fontSize: 18),
                                )),
                          ),
                          SizedBox(
                            height: 100,
                            width: 100,
                            child: Container(
                                alignment: Alignment.center,
                                color: Colors.blue,
                                child: Text(
                                  "Container 2",
                                  style: TextStyle(fontSize: 18),
                                )),
                          ),
                          SizedBox(
                            height: 100,
                            width: 100,
                            child: Container(
                                alignment: Alignment.center,
                                color: Colors.yellow,
                                child: Text(
                                  "Container 3",
                                  style: TextStyle(fontSize: 18),
                                )),
                          ),
                          SizedBox(
                            height: 100,
                            width: 100,
                            child: Container(
                                alignment: Alignment.center,
                                color: Colors.purple,
                                child: Text(
                                  "Container 4",
                                  style: TextStyle(fontSize: 18),
                                )),
                          ),
                          SizedBox(
                            height: 100,
                            width: 100,
                            child: Container(
                                alignment: Alignment.center,
                                color: Colors.green,
                                child: Text(
                                  "Container 5",
                                  style: TextStyle(fontSize: 18),
                                )),
                          ),
                        ],
                      ),
                    ),
                    Container(
                      padding: EdgeInsets.all(20),
                      child: Column(
                        children: [
                          Container(
                            child: Text(
                              "ItGrid - manyItens",
                              style: TextStyle(fontSize: 16),
                            ),
                          )
                        ],
                      ),
                    ),
                    Container(
                      child: ItGrid(
                        columns: 5,
                        children: [
                          SizedBox(
                            height: 100,
                            width: 100,
                            child: Container(
                                alignment: Alignment.center,
                                color: Colors.red,
                                child: Text(
                                  "Container 1",
                                  style: TextStyle(fontSize: 18),
                                )),
                          ),
                          SizedBox(
                            height: 100,
                            width: 100,
                            child: Container(
                                alignment: Alignment.center,
                                color: Colors.blue,
                                child: Text(
                                  "Container 2",
                                  style: TextStyle(fontSize: 18),
                                )),
                          ),
                          SizedBox(
                            height: 100,
                            width: 100,
                            child: Container(
                                alignment: Alignment.center,
                                color: Colors.yellow,
                                child: Text(
                                  "Container 3",
                                  style: TextStyle(fontSize: 18),
                                )),
                          ),
                          SizedBox(
                            height: 100,
                            width: 100,
                            child: Container(
                                alignment: Alignment.center,
                                color: Colors.purple,
                                child: Text(
                                  "Container 4",
                                  style: TextStyle(fontSize: 18),
                                )),
                          ),
                          SizedBox(
                            height: 100,
                            width: 100,
                            child: Container(
                                alignment: Alignment.center,
                                color: Colors.green,
                                child: Text(
                                  "Container 5",
                                  style: TextStyle(fontSize: 18),
                                )),
                          ),
                          SizedBox(
                            height: 100,
                            width: 100,
                            child: Container(
                                alignment: Alignment.center,
                                color: Colors.grey,
                                child: Text(
                                  "Container 6",
                                  style: TextStyle(fontSize: 18),
                                )),
                          ),
                          SizedBox(
                            height: 100,
                            width: 100,
                            child: Container(
                                alignment: Alignment.center,
                                color: Colors.amber,
                                child: Text(
                                  "Container 7",
                                  style: TextStyle(fontSize: 18),
                                )),
                          ),
                          SizedBox(
                            height: 100,
                            width: 100,
                            child: Container(
                                alignment: Alignment.center,
                                color: Colors.orange,
                                child: Text(
                                  "Container 8",
                                  style: TextStyle(fontSize: 18),
                                )),
                          ),
                        ],
                      ),
                    ),
                    Container(
                      padding: EdgeInsets.all(20),
                      child: Column(
                        children: [
                          Container(
                            child: Text(
                              "ItRate",
                              style: TextStyle(fontSize: 16),
                            ),
                          )
                        ],
                      ),
                    ),
                    for (int i = 0; i <= 10; i++)
                      ItRate(
                        rate: i,
                        mainAxisAlignment: MainAxisAlignment.center,
                        fullIcon: Icons.star_rate_rounded,
                        halfIcon: Icons.star_half_rounded,
                        emptyIcon: Icons.star_border_rounded,
                        iconSize: 40,
                      ),
                    Container(
                      padding: EdgeInsets.all(20),
                      child: Column(
                        children: [
                          Container(
                            child: Text(
                              "ItTextField",
                              style: TextStyle(fontSize: 16),
                            ),
                          )
                        ],
                      ),
                    ),
                    Container(
                        padding: EdgeInsets.all(10),
                        child: ItTextField(style: TextStyle(fontSize: 20))),
                    Container(
                        padding: EdgeInsets.all(10),
                        child: ItTextField(
                          style: TextStyle(fontSize: 20),
                          leftItem: Icon(Icons.ac_unit_outlined),
                        )),
                    Container(
                        padding: EdgeInsets.all(10),
                        child: ItTextField(
                          style: TextStyle(fontSize: 20),
                          rightItem: Icon(Icons.ac_unit_outlined),
                        )),
                    Container(
                        padding: EdgeInsets.all(10),
                        child: ItTextField(
                          style: TextStyle(fontSize: 20),
                          leftItem: Icon(Icons.ac_unit_outlined),
                          rightItem: Icon(Icons.ac_unit_outlined),
                        )),
                    Container(
                        padding: EdgeInsets.all(10),
                        child: ItTextField(
                          style: TextStyle(fontSize: 20),
                          leftItem: Icon(Icons.ac_unit_outlined),
                          rightItem: Icon(Icons.ac_unit_outlined),
                          bgColor: Colors.red,
                        )),
                    Container(
                        padding: EdgeInsets.all(10),
                        child: ItTextField(
                          style: TextStyle(fontSize: 20),
                          leftItem: Icon(Icons.ac_unit_outlined),
                          rightItem: Icon(Icons.ac_unit_outlined),
                          bgColor: Colors.red,
                          hintText: "Test",
                        )),
                    Container(
                        padding: EdgeInsets.all(10),
                        child: ItTextField(
                          style: TextStyle(fontSize: 20),
                          leftItem: Icon(Icons.ac_unit_outlined),
                          rightItem: Icon(Icons.ac_unit_outlined),
                          hintText: "Test",
                          underlineColor: Colors.purple,
                          lineHeight: 4,
                        )),
                  ],
                ),
              ),
            ),
          ),
        ));
  }
}
